@@ -250,6 +250,8 @@ impl<T, A: Allocator> Vec<T, A> {
     }
 
     /// Leaks self into a slice of `T`, without deallocating any elements or excess capacity
+    ///
+    /// This will permanently leak the allocation and it's elements
     pub fn leak<'a>(self) -> &'a mut [T]
     where
         A: 'a,
@@ -301,6 +303,82 @@ impl<T, A: Allocator> Vec<T, A> {
     pub fn as_ptr(&self) -> *const T {
         self.ptr.as_ptr()
     }
+
+    /// Removes the elements from `n` to the end and returns them in a new [`Vec`]
+    ///
+    /// # Panics
+    ///
+    /// If `n` is greater than len
+    #[must_use = "If you don't need the split off elements use `Self::shrink` instead"]
+    pub fn split_off(&mut self, n: usize) -> Self
+    where
+        A: Clone,
+    {
+        assert!(n <= self.len);
+        let nlen = self.len - n;
+        let mut new = Self::with_capacity_in(nlen, self.alloc.clone());
+        unsafe {
+            self.set_len(n);
+        }
+        let src = unsafe { self.ptr.as_ptr().add(n) };
+        let dst = new.ptr.as_ptr();
+        for i in 0..nlen {
+            unsafe { dst.add(i).write(src.add(i).read()) }
+        }
+        unsafe {
+            new.set_len(nlen);
+        }
+        new
+    }
+
+    /// Removes the last `n` returns them in a new [`Vec`]
+    ///
+    /// # Panics
+    ///
+    /// If `n` is greater than len
+    #[must_use = "If you don't need the split off elements use `Self::shrink` instead"]
+    pub fn split_off_back(&mut self, n: usize) -> Self
+    where
+        A: Clone,
+    {
+        assert!(n <= self.len);
+        let nlen = self.len - n;
+        let mut new = Self::with_capacity_in(n, self.alloc.clone());
+        unsafe {
+            self.set_len(nlen);
+        }
+        let src = unsafe { self.ptr.as_ptr().add(nlen) };
+        let dst = new.ptr.as_ptr();
+        for i in 0..n {
+            unsafe { dst.add(i).write(src.add(i).read()) }
+        }
+        unsafe {
+            new.set_len(n);
+        }
+        new
+    }
+
+    ///
+    /// Resizes the vector, shrinking it to `nlen`, dropping any excees elements
+    ///
+    /// # Panics
+    /// Panics if `nlen` is greater than than `self.len()`
+    pub fn shrink(&mut self, new_len: usize) {
+        assert!(new_len <= self.len);
+
+        let old_len = self.len;
+
+        unsafe {
+            self.set_len(new_len);
+        }
+
+        if core::mem::needs_drop::<T>() {
+            let ptr = self.ptr.as_ptr();
+            for i in new_len..old_len {
+                unsafe { core::ptr::drop_in_place(ptr.add(i)) }
+            }
+        }
+    }
 }
 
 impl<T, A: Allocator + Default> FromIterator<T> for Vec<T, A> {
@@ -586,3 +664,130 @@ macro_rules! vec{
 
     }
 }
+
+#[cfg(test)]
+mod test {
+    use super::Vec;
+    #[test]
+    fn test_vec_new() {
+        let vec = Vec::<u32>::new();
+
+        assert_eq!(vec.len(), 0);
+    }
+
+    #[test]
+    fn test_vec_empty() {
+        let vec: Vec<u32> = vec![];
+        assert_eq!(vec.len(), 0);
+    }
+
+    #[test]
+    fn test_vec_push() {
+        let mut vec = Vec::new();
+        vec.push(0);
+        assert_eq!(vec.len(), 1);
+    }
+
+    #[test]
+    fn test_vec_deref() {
+        let mut vec = Vec::new();
+        vec.push(0);
+        assert!(matches!(*vec, [0]));
+    }
+
+    #[test]
+    fn test_vec_iter() {
+        let mut vec = Vec::new();
+        vec.push(1);
+
+        let mut iter = vec.iter();
+        assert_eq!(iter.next(), Some(&1));
+    }
+
+    #[test]
+    fn test_vec_subscript() {
+        let mut vec = Vec::new();
+        vec.push(1);
+
+        assert_eq!(vec[0], 1);
+    }
+
+    #[test]
+    #[should_panic]
+    fn test_vec_subscript_oob() {
+        let mut vec = Vec::new();
+        vec.push(1);
+        vec.push(2);
+
+        let _ = vec[2];
+    }
+
+    #[test]
+    fn test_vec_get() {
+        let mut vec = Vec::new();
+        vec.push(1);
+
+        assert_eq!(vec.get(0), Some(&1));
+    }
+
+    #[test]
+    fn test_vec_get_oob() {
+        let mut vec = Vec::new();
+        vec.push(1);
+
+        assert_eq!(vec.get(1), None);
+    }
+
+    #[test]
+    fn test_vec_get_unchecked() {
+        let mut vec = Vec::new();
+        vec.push(1);
+        vec.push(2);
+
+        assert_eq!(unsafe { vec.get_unchecked(1) }, &2);
+    }
+
+    #[test]
+    fn test_vec_slice() {
+        let mut vec = Vec::new();
+        vec.push(1);
+        vec.push(2);
+        vec.push(3);
+
+        assert!(matches!(vec[..2], [1, 2]));
+    }
+
+    #[test]
+    fn test_vec_slice_inclusive_bound() {
+        let mut vec = Vec::new();
+        vec.push(1);
+        vec.push(2);
+        vec.push(3);
+
+        assert!(matches!(vec[..=2], [1, 2, 3]));
+    }
+
+    #[test]
+    fn test_vec_slice_full() {
+        let mut vec = Vec::new();
+        vec.push(1);
+        vec.push(2);
+        vec.push(3);
+
+        assert!(matches!(vec[..], [1, 2, 3]));
+    }
+
+    #[test]
+    fn test_vec_iter_mut() {
+        let mut vec = Vec::new();
+        vec.push(1);
+        vec.push(2);
+
+        let mut iter_mut = vec.iter_mut();
+        *iter_mut.next().unwrap() += 3;
+        *iter_mut.next().unwrap() += 3;
+
+        assert_eq!(vec[0], 4);
+        assert_eq!(vec[1], 5);
+    }
+}
